@@ -399,7 +399,7 @@ def edit_config(model_selected, input_config_dir, output_config_dir, num_steps,
 
     configs = config_util.get_configs_from_pipeline_file(os.path.join(input_config_dir,'pipeline.config'))
     label_map = label_map_util.load_labelmap(label_map_path)
-    num_steps += configs["train_config"].num_steps
+    # num_steps += configs["train_config"].num_steps
     config_util._update_train_steps(configs, num_steps)
     update_different_paths(configs, ckpt_path=ckpt_path, 
                             label_map_path=label_map_path, 
